# ORATS Python SDK

> **BEWARE** This project is **unstable** and in early stages of development!

This project is a wrapper around [ORATS](https://orats.com/) APIs.

![Docs](../../actions/workflows/build-docs.yml/badge.svg)
![Tests](../../actions/workflows/run-tests.yml/badge.svg)

> **NOTE**: ORATS offers numerous subscription services.
Depending on your personal subscriptions, you will be issued an API key with
appropriate permissions. Some functionality in this SDK may not be accessible
if you are not subscribed to the necessary services.

## Project Structure

### Development Tooling

- Source Control Management: [Git](https://git-scm.com/) + [GitHub](https://github.com/)
- Documentation: [Sphinx](https://www.sphinx-doc.org/) + [GitHub Pages](https://pages.github.com/)
- CI/CD: [GitHub Actions](https://github.com/features/actions)
- Code Style: [Black](https://pypi.org/project/black/)
- Type Checker: [mypy](http://mypy-lang.org/)
- Test Runner: [tox](https://tox.wiki/) + [pytest](https://docs.pytest.org/)
